==> docfbe_2_3_35_62.zip: docfbe_2_2_35_62/source/TCFbECsvOutputFormatter.h <==
/*
    TCFbECsvOutputFormatter.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbECsvOutputFormatterH
#define TCFbECsvOutputFormatterH
//---------------------------------------------------------------------------
#include <stdio.h>
#include <system.hpp>
#include <SysUtils.hpp>

#include "TCFbEOutputFormatter.h"
#include "TCFbECommandLineParser.h"
#include "TCFbEOutputCash.h"
//---------------------------------------------------------------------------
class TCFbECsvOutputFormatter : public TCFbEOutputFormatter
{
public:
    virtual __fastcall TCFbECsvOutputFormatter(TCFbECommandLineParser* Parser, TCFbEOutputCash* OutputCash, bool IsVerbose=false);    // RXgN^
    __fastcall ~TCFbECsvOutputFormatter();    // fXgN^

protected:
    virtual void __fastcall OutputHeader(void);    // wb_ this->FOutputStringList ɒǉDwb_KvłȂꍇ͂ return D
    virtual void __fastcall OutputBody(int TargetRowIndex);    // {fB this->FOutputStringList ɒǉD

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_3_46_82.zip: docfbe_2_3_46_82/source/TCFbECsvOutputFormatter.h <==
/*
    TCFbECsvOutputFormatter.h    June 6, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbECsvOutputFormatterH
#define TCFbECsvOutputFormatterH
//---------------------------------------------------------------------------
#include <stdio.h>
#include <system.hpp>
#include <SysUtils.hpp>

#include "TCFbEOutputFormatter.h"
#include "TCFbEDocfbeCommandLineParser.h"
#include "TCFbEOutputCache.h"
//---------------------------------------------------------------------------
class TCFbECsvOutputFormatter : public TCFbEOutputFormatter
{
public:
    virtual __fastcall TCFbECsvOutputFormatter(TCFbEDocfbeCommandLineParser* Parser, TCFbEOutputCache* OutputCache, bool IsVerbose=false);    // RXgN^
    __fastcall ~TCFbECsvOutputFormatter();    // fXgN^

protected:
    virtual void __fastcall OutputHeader(void);    // wb_ this->FOutputStringList ɒǉDwb_KvłȂꍇ͂ return D
    virtual void __fastcall OutputBody(int TargetRowIndex);    // {fB this->FOutputStringList ɒǉD

private:

};
//---------------------------------------------------------------------------
#endif
